pub enum DotHandlingPolicy {
ReplaceAllDots,
PreserveAllDots,
PreserveDotsBetweenDecimalDigits,
}Expand description
Dot handling before all other filtered characters become delimiters.
Variants
ReplaceAllDots
Treat every dot as a delimiter.
PreserveAllDots
Preserve every dot.
PreserveDotsBetweenDecimalDigits
Preserve a dot only when the previous and next characters are decimal digits.