pub enum SlugError {
EmptyTransliterationPattern,
EmptyPathSegment,
PathSegmentSeparator {
character: char,
},
PathSegmentWhitespace {
character: char,
},
PathSegmentControlCharacter {
character: char,
},
PathSegmentDotValue,
UrlPathSegmentReservedCharacter {
character: char,
},
FallbackViolatesConfig {
reason: &'static str,
},
AmbiguousReplacementDelimiter {
delimiter: char,
reason: &'static str,
},
}Expand description
Errors returned by slug generation or validation.
Variants
EmptyTransliterationPattern
A static transliteration map contains an empty pattern.
EmptyPathSegment
A path segment cannot be empty.
PathSegmentSeparator
A path segment cannot contain / or \.
PathSegmentWhitespace
A path segment cannot contain Unicode whitespace.
PathSegmentControlCharacter
A path segment cannot contain control characters.
PathSegmentDotValue
A path segment cannot be . or ...
UrlPathSegmentReservedCharacter
A URL path segment cannot contain URL delimiter or raw percent characters.
FallbackViolatesConfig
A EmptyOutputPolicy::UseFallbackSlug value does not satisfy the
configuration that produced the slug it replaces.
AmbiguousReplacementDelimiter
The replacement delimiter is a character this configuration would also keep from the input, so the two could not be told apart.